@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 
 from trytond.model import ModelSQL, ModelView, fields
@@ -8,10 +8,9 @@ from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
 
 __all__ = ['Carrier', 'WeightPriceList']
-__metaclass__ = PoolMeta
 
 
-class Carrier:
+class Carrier(metaclass=PoolMeta):
     __name__ = 'carrier'
     weight_uom = fields.Many2One('product.uom', 'Weight Uom',
         domain=[('category', '=', Id('product', 'uom_cat_weight'))],
@@ -20,18 +19,20 @@ class Carrier:
             'required': Eval('carrier_cost_method') == 'weight',
             'readonly': Bool(Eval('weight_price_list', [])),
             },
-        depends=['carrier_cost_method', 'weight_price_list'])
-    weight_uom_digits = fields.Function(fields.Integer('Weight Uom Digits',
-            on_change_with=['weight_uom']), 'on_change_with_weight_uom_digits')
+        depends=['carrier_cost_method', 'weight_price_list'],
+        help="The unit of weight criteria of the price list.")
+    weight_uom_digits = fields.Function(fields.Integer('Weight Uom Digits'),
+        'on_change_with_weight_uom_digits')
     weight_currency = fields.Many2One('currency.currency', 'Currency',
         states={
             'invisible': Eval('carrier_cost_method') != 'weight',
             'required': Eval('carrier_cost_method') == 'weight',
             'readonly': Bool(Eval('weight_price_list', [])),
             },
-        depends=['carrier_cost_method', 'weight_price_list'])
+        depends=['carrier_cost_method', 'weight_price_list'],
+        help="The currency of the price.")
     weight_currency_digits = fields.Function(fields.Integer(
-            'Weight Currency Digits', on_change_with=['weight_currency']),
+            'Weight Currency Digits'),
         'on_change_with_weight_currency_digits')
     weight_price_list = fields.One2Many('carrier.weight_price_list', 'carrier',
         'Price List',
@@ -39,7 +40,8 @@ class Carrier:
             'invisible': Eval('carrier_cost_method') != 'weight',
             'readonly': ~(Eval('weight_uom', 0) & Eval('weight_currency', 0)),
             },
-        depends=['carrier_cost_method', 'weight_uom', 'weight_currency'])
+        depends=['carrier_cost_method', 'weight_uom', 'weight_currency'],
+        help="Add price to the carrier service.")
 
     @classmethod
     def __setup__(cls):
@@ -60,11 +62,13 @@ class Carrier:
             return Company(company).currency.digits
         return 2
 
+    @fields.depends('weight_uom')
     def on_change_with_weight_uom_digits(self, name=None):
         if self.weight_uom:
             return self.weight_uom.digits
         return 2
 
+    @fields.depends('weight_currency')
     def on_change_with_weight_currency_digits(self, name=None):
         if self.weight_currency:
             return self.weight_currency.digits
@@ -99,11 +103,15 @@ class Carrier:
 class WeightPriceList(ModelSQL, ModelView):
     'Carrier Weight Price List'
     __name__ = 'carrier.weight_price_list'
-    carrier = fields.Many2One('carrier', 'Carrier', required=True, select=True)
+    carrier = fields.Many2One('carrier', 'Carrier', required=True, select=True,
+        help="The carrier that the price list belongs to.")
     weight = fields.Float('Weight',
-        digits=(16, Eval('_parent_carrier.weight_uom_digits', 2)))
+        digits=(16, Eval('_parent_carrier', {}).get('weight_uom_digits', 2)),
+        help="The upper limit for the price.")
     price = fields.Numeric('Price',
-        digits=(16, Eval('_parent_carrier.weight_currency_digits', 2)))
+        digits=(16, Eval('_parent_carrier', {}).get(
+                'weight_currency_digits', 2)),
+        help="The price of the carrier service.")
 
     @classmethod
     def __setup__(cls):
